<?php

/*
 * This file is part of Respect/Validation.
 *
 * (c) Alexandre Gomes Gaigalas <alexandre@gaigalas.net>
 *
 * For the full copyright and license information, please view the "LICENSE.md"
 * file that was distributed with this source code.
 */

namespace Respect\Validation;

use RecursiveIteratorIterator;

final class Validation
{
    /**
     * @var Result
     */
    private $result;

    /**
     * @var Factory
     */
    private $factory;

    public function __construct(Result $result, Factory $factory)
    {
        $this->result = $result;
        $this->factory = $factory;
    }

    public function isValid(): bool
    {
        return $this->result->isValid();
    }

    private function messages(Result $parentResult)
    {
        $parentKey = spl_object_hash($parentResult);
        $parentMessage = $this->factory->message($parentResult);

        $messages = [];
        $messages[$parentKey] = $parentMessage->__toString();

        foreach ($parentResult as $key => $result) {
            if (!is_string($key)) {
                $key = spl_object_hash($result);
            }

            $message = $this->factory->message($result);

            if (!$result->hasChildren()) {
                $messages[$key] = $message->__toString();
                continue;
            }

            $messages[$key] = $this->messages($result);
            if (count($messages[$key]) == 1) {
                $messages[$key] = current($messages[$key]);
            }

            if ($message->isIgnorable()) {
                continue;
            }
        }

        if ($parentMessage->isIgnorable() && count($messages) > 1) {
             unset($messages[$parentKey]);
        }

        return $messages;
    }

    public function getMessage(): string
    {
        return current($this->getMessages());
    }

    public function getMessages(): array
    {
        return $this->messages($this->result);
    }
}
